nameko.standalone package
=========================

Submodules
----------

.. toctree::

   nameko.standalone.events
   nameko.standalone.rpc

Module contents
---------------

.. automodule:: nameko.standalone
    :members:
    :undoc-members:
    :show-inheritance:
